@@ -1,12 +1,17 @@
-( cd opt/kde/share/doc/HTML/en/kcron ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcron ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kuser ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kuser ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kpackage ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kpackage ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/lilo-config ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/lilo-config ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/ksystemlog ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/ksystemlog ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kpackage ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kpackage ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcron ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcron ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/knetworkconf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/knetworkconf ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/ksystemlog ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/ksystemlog ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kuser ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kuser ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+#%% begin initialize kdeadmin-4.3.1
+if [ -f /opt/kde/bin/plamo_update_kde.sh ]; then
+	/bin/bash /opt/kde/bin/plamo_update_kde.sh
+fi
+#%% end
